@@ -200,6 +200,12 @@ class MyWindow(Gtk.ApplicationWindow):
 
     def launch(self, title, icon_name, path):
         """Launch the specified application"""
+        if self.launcher.embeddable:
+            self.embedded_launch(title, icon_name, path)
+        else:
+            self.unembedded_launch(title, icon_name, path)
+
+    def embedded_launch(self, title, icon_name, path):
         # Toggle GTK_CSD=0 to guarantee embedding
         csd_env = os.environ.copy()
         csd_env["GTK_CSD"] = "0"
@@ -218,10 +224,45 @@ class MyWindow(Gtk.ApplicationWindow):
 
         def on_success():
             self.set_view("game", icon_name, title)
+
+        def on_error():
+            return self.back_to_launcher()
+
         self.launcher.launch(self.socket, self.game_process,
-                             on_success, self.back_to_launcher)
+                             on_success, on_error)
+
+    def unembedded_launch(self, title, icon_name, path):
+        subtitle = _("Loading %s") % title
+
+        if os.path.isfile(icon_name):
+            self.launching_image.set_from_file(icon_name)
+        else:
+            self.launching_image.set_from_icon_name(icon_name,
+                                                    Gtk.IconSize.DIALOG)
+        self.launching_title.set_markup("<b>%s</b>" % title)
+        self.set_view("loading", icon_name, subtitle)
+
+        def poll_process():
+            res = GLib.SOURCE_CONTINUE
+            if self.game_process is None:
+                res = GLib.SOURCE_REMOVE
+            if self.game_process.poll() is not None:
+                res = GLib.SOURCE_REMOVE
+            if res == GLib.SOURCE_REMOVE:
+                self.back_to_launcher()
+            return res
+
+        def launch_game():
+            self.game_process = subprocess.Popen([path])
+            self.hide()
+            GLib.timeout_add(200, poll_process)
+            return GLib.SOURCE_REMOVE
+
+        GLib.timeout_add(500, launch_game)
 
     def back_to_launcher(self):
+        if not self.launcher.embeddable:
+            self.show()
         if self.game_process is not None:
             self.game_process.terminate()
             self.game_process = None
@@ -229,13 +270,13 @@ class MyWindow(Gtk.ApplicationWindow):
 
     def set_view(self, name, icon_name=None, subtitle=None):
         """Change the view, setting the icon name and subtitle"""
-        if name is "launcher":
+        if name == "launcher":
             self.stack.set_transition_type(Gtk.StackTransitionType.OVER_RIGHT)
             self.hide_actions()
-        if name is "loading":
+        if name == "loading":
             self.stack.set_transition_type(Gtk.StackTransitionType.OVER_LEFT)
             self.hide_actions()
-        if name is "game":
+        if name == "game":
             self.stack.set_transition_type(Gtk.StackTransitionType.OVER_LEFT)
             self.show_actions()
 
@@ -247,7 +288,7 @@ class MyWindow(Gtk.ApplicationWindow):
         else:
             title = "%s - %s" % (title, subtitle)
 
-        if name is not "launcher" and os.path.isfile(icon_name):
+        if name != "launcher" and os.path.isfile(icon_name):
             self.set_default_icon_from_file(icon_name)
         else:
             self.set_default_icon_name(icon_name)
@@ -257,7 +298,7 @@ class MyWindow(Gtk.ApplicationWindow):
 
         self.get_window().set_title(title)
 
-        if name is "game":
+        if name == "game":
             self.socket.grab_focus()
         else:
             self.grab_focus()
@@ -326,7 +367,7 @@ class MyAboutDialog(Gtk.AboutDialog):
         self.set_artists([
             "Pasi Lallinaho"
         ])
-        self.set_website("https://launchpad.net/sgt-launcher")
+        self.set_website("https://github.com/bluesabre/sgt-launcher")
         self.set_license_type(Gtk.License.GPL_3_0)
         self.set_version(sgtlauncher_lib.get_version())
 
@@ -424,7 +465,7 @@ class MyApplication(Gtk.Application):
 
     def bugreport_cb(self, action, parameter):
         """Take the user to the bug reporting platform"""
-        uri = "https://bugs.launchpad.net/sgt-launcher"
+        uri = "https://github.com/bluesabre/sgt-launcher/issues"
         Gtk.show_uri_on_window(self.win, uri, Gdk.CURRENT_TIME)
 
     def quit_cb(self, action, parameter):
@@ -446,10 +487,12 @@ class MyApplication(Gtk.Application):
     def get_launchers(self):
         """Get localized launcher contents"""
         flags = GLib.KeyFileFlags.NONE
-        launchers = []
+        prefixed = {}
         for game in self.GAMES:
-            for prefix in ["sgt", "puzzle"]:
-                launcher = "applications/%s-%s.desktop" % (prefix, game)
+            for prefix in ["sgt-", "puzzle-", ""]:
+                if prefix not in prefixed.keys():
+                    prefixed[prefix] = []
+                launcher = "applications/%s%s.desktop" % (prefix, game)
                 keyfile = GLib.KeyFile.new()
                 try:
                     if (keyfile.load_from_data_dirs(launcher, flags)):
@@ -460,9 +503,13 @@ class MyApplication(Gtk.Application):
                             keyfile.get_value("Desktop Entry", "Exec"),
                         ]
                         if self.exists_in_path(data[3]):
-                            launchers.append(data)
+                            prefixed[prefix].append(data)
                     break
                 except GLib.Error:
                     pass
+        launchers = []
+        for items in prefixed.values():
+            if len(items) > len(launchers):
+                launchers = items
         launchers.sort()
         return launchers
