@@ -35,10 +35,13 @@ def parse_options():
 
 
 def main():
-    """Main application for SGT Launcher"""
+    """Main application for SGT Puzzles Collection"""
     parse_options()
 
     # Run the application.
     app = SgtLauncher.MyApplication()
-    exit_status = app.run(None)
+    try:
+        exit_status = app.run(None)
+    except KeyboardInterrupt:
+        exit_status = 130
     sys.exit(exit_status)
